@@ -1,13 +1,13 @@
 from pybliometrics.scopus.utils import *
 
-from pybliometrics.scopus.abstract_citations import *
+from pybliometrics.scopus.abstract_citation import *
 from pybliometrics.scopus.abstract_retrieval import *
 from pybliometrics.scopus.affiliation_retrieval import *
 from pybliometrics.scopus.affiliation_search import *
 from pybliometrics.scopus.author_retrieval import *
-from pybliometrics.scopus.plumx_metrics import *
 from pybliometrics.scopus.author_search import *
+from pybliometrics.scopus.plumx_metrics import *
 from pybliometrics.scopus.scopus_search import *
 from pybliometrics.scopus.serial_search import *
 from pybliometrics.scopus.serial_title import *
-
+from pybliometrics.scopus.subject_classifications import *
