@@ -61,7 +61,7 @@ class AuthorSearch(Search):
                  integrity_fields: Union[List[str], Tuple[str, ...]] = None,
                  integrity_action: str = "raise",
                  count: int = 200,
-                 **kwds
+                 **kwds: str
                  ) -> None:
         """Interaction with the Author Search API.
 
