@@ -14,10 +14,10 @@ s2 = AuthorSearch('authlast(selten)', download=False, refresh=True)
 def test_authors():
     assert_true(isinstance(s1.authors, list))
     assert_true(len(s1.authors) >= 2)
-    order = 'eid surname initials givenname affiliation documents '\
+    order = 'eid orcid surname initials givenname affiliation documents '\
             'affiliation_id city country areas'
     Author = namedtuple('Author', order)
-    expected = Author(eid='9-s2.0-6602907525', surname='Selten',
+    expected = Author(eid='9-s2.0-6602907525', orcid=None, surname='Selten',
         initials='R.', givenname='Reinhard', affiliation='Universität Bonn',
         documents=74, affiliation_id='60007493', city='Bonn',
         country='Germany', areas='ECON (73); MATH (19); BUSI (16)')
