@@ -18,6 +18,7 @@ def create_config(keys: Optional[List[str]] = None,
     config = configparser.ConfigParser()
     config.optionxform = str
     print(f"Creating config file at {CONFIG_FILE} with default paths...")
+
     # Set directories
     config.add_section('Directories')
     for api, path in DEFAULT_PATHS.items():
@@ -43,6 +44,10 @@ def create_config(keys: Optional[List[str]] = None,
     if token:
         config.set('Authentication', 'InstToken', token)
 
+    # Set default values
+    config.add_section('Requests')
+    config.set('Requests', 'Timeout', '20')
+
     # Write out
     CONFIG_FILE.parent.mkdir(parents=True, exist_ok=True)
     with open(CONFIG_FILE, "w") as ouf:
