@@ -9,10 +9,11 @@ user_agent = 'pybliometrics-v' + '.'.join([str(e) for e in version_info[:3]])
 
 errors = {400: exception.Scopus400Error, 401: exception.Scopus401Error,
           403: exception.Scopus403Error, 404: exception.Scopus404Error,
-          413: exception.Scopus413Error, 414: exception.Scopus414Error,
-          429: exception.Scopus429Error, 500: exception.Scopus500Error,
-          502: exception.Scopus502Error}
+          407: exception.Scopus407Error, 413: exception.Scopus413Error, 
+          414: exception.Scopus414Error, 429: exception.Scopus429Error, 
+          500: exception.Scopus500Error, 502: exception.Scopus502Error}
 
+session = requests.Session()
 
 def get_content(url, api, params=None, **kwds):
     """Helper function to download a file and return its content.
@@ -55,9 +56,13 @@ def get_content(url, api, params=None, **kwds):
     from pybliometrics.scopus.utils.startup import _throttling_params, KEYS
 
     # Set header, params and proxy
-    header = {'X-ELS-APIKey': KEYS[0],
+    try:
+        header = {'X-ELS-APIKey': KEYS[0],
               'Accept': 'application/json',
               'User-Agent': user_agent}
+    except IndexError:
+        raise errors[429]
+
     if config.has_option('Authentication', 'InstToken'):
         token = config.get('Authentication', 'InstToken')
         header['X-ELS-Insttoken'] = token
@@ -77,16 +82,18 @@ def get_content(url, api, params=None, **kwds):
             sleep(1 - (time() - _throttling_params[api][0]))
         except (IndexError, ValueError):
             pass
-
+    
     # Perform request, eventually replacing the current key
-    resp = requests.get(url, headers=header, proxies=proxies, params=params)
+    timeout = config.getint("Requests", "Timeout", fallback=20)
+    resp = session.get(url, headers=header, proxies=proxies, params=params,
+                      timeout=timeout)
     while resp.status_code == 429:
         try:
             KEYS.pop(0)  # Remove current key
             shuffle(KEYS)
             header['X-ELS-APIKey'] = KEYS[0].strip()
-            resp = requests.get(url, headers=header, proxies=proxies,
-                                params=params)
+            resp = session.get(url, headers=header, proxies=proxies,
+                               params=params, timeout=timeout)
         except IndexError:  # All keys depleted
             break
     _throttling_params[api].append(time())
