@@ -1,6 +1,10 @@
 from collections import namedtuple
+from functools import reduce
 from warnings import warn
 
+def filter_digits(s):
+    """Helper function to remove non-digits characters from a string."""
+    return "".join(filter(str.isdigit, s))
 
 def chained_get(container, path, default=None):
     """Helper function to perform a series of .get() methods on a dictionary
@@ -18,8 +22,6 @@ def chained_get(container, path, default=None):
         The object type that should be returned if the search yields
         no result.
     """
-    from functools import reduce
-
     # Obtain value via reduce
     try:
         return reduce(lambda c, k: c.get(k, default), path, container)
@@ -52,6 +54,14 @@ def check_field_consistency(needles, haystack):
         raise ValueError(msg)
 
 
+def deduplicate(lst):
+    """Auxiliary function to deduplicate a list while preserving its order."""
+    new = reduce(lambda x, y: x + y if y[0] not in x else x,
+                 map(lambda x: [x], lst),
+                 [])
+    return new
+
+
 def get_id(s, integer=True):
     """Helper function to return the Scopus ID at a fixed position."""
     path = ['coredata', 'dc:identifier']
